﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SE.GOV.MM.Integration.Log
{
    /// <summary>
    /// Different EventIds shown in Windows eventviewer.
    /// </summary>
    public enum EventId
    {
        //Error
        /// <summary>
        /// Exception
        /// </summary>
        GenerelizedException = 100,
        /// <summary>
        /// Exception when not reaching the Mina meddelanden webservice Recipient
        /// </summary>
        CommunicationExceptionWithRecipient = 101,
        /// <summary>
        /// Exception when not reaching the Mina meddelanden dispatcher Message
        /// </summary>
        CommunicationExceptionWithMessage = 102,
        /// <summary>
        /// Exception when client cant find or connect to FaRService
        /// </summary>
        CommunicationExceptionWithFaR = 103,
        /// <summary>
        /// Exception when client cant find or connect to PackageService
        /// </summary>
        CommunicationExceptionWithPackage = 104,
        /// <summary>
        /// Exception when Delivery or Package cant reach Sql database
        /// </summary>
        SqlDatabaseNotAvailable = 105,
        /// <summary>
        /// Exception when Delivery or Package cant write to Sql database
        /// </summary>
        SqlDatabaseExceptionWriting = 106,
        /// <summary>
        /// Exception when Delivery or Package cant read from Sql database
        /// </summary>
        SqlDatabaseExceptionReading = 107,
        /// <summary>
        /// ConfigurationKey is missing in the app.config or web.config files.
        /// </summary>
        ConfigurationExceptionMissingKey = 108,
        /// <summary>
        /// Cant read the xml file in ConfigurationService that is holding the allowed attachment extensions.
        /// </summary>
        ConfigurationException = 109,
        /// <summary>
        /// If an incoming call has an invalid argument or not formatted properly
        /// </summary>
        ArgumentException = 110,
        /// <summary>
        /// Cant find the certificate used to sign xml files.
        /// </summary>
        SigningCertificateNotAvailable = 111,
        /// <summary>
        /// Exception when signing the message
        /// </summary>
        XmlDocumentSigningException = 112,
        /// <summary>
        /// CommunicationException when connecting to DeliveryMailbox
        /// </summary>
        CommunicationExceptionWithDeliveryMailbox = 113,
        /// <summary>
        /// CommunicationException when connecting to DeliveryMailbox
        /// </summary>
        CommunicationExceptionWithService = 114,
        /// <summary>
        /// Information
        /// </summary>
        Information = 500,
        /// <summary>
        /// Warning
        /// </summary>
        Warning = 600
    }
}
